@@ -1,3 +1,5 @@
+from typing import Optional
+
 from .action_executor import ActionExecutor
 from ...common.action import Action
 from ...utils.utils import ignore
@@ -6,7 +8,7 @@ from ...utils.utils import ignore
 
 class ExecutorFactory():
     @staticmethod
-    def get_executor_for(action: Action) -> ActionExecutor:
+    def get_executor_for(action: Action) -> Optional[ActionExecutor]:
         # Abstract.
         ignore(action)
 
